bonuslabgroup8-package: Introduction to Machine Learning in R

Description Details Author(s) References

Description

This package contains two functions. The first is an alternative to the linear regression package, this functions is called ridgereg and returns an object with the results of a Ridge regression. The second is a visualisation of mean delay of flights for different airports by longitude and latitude.

Details

The DESCRIPTION file: This package was not yet installed at build time.

Index: This package was not yet installed at build time.
~~ An overview of how to use the package, including the most ~~ ~~ important functions ~~

Author(s)

c(person("Bayu Beta", "Brahmantio", email = "bayubrahmantio@gmail.com", role = c("aut", "cre")), person("Joris", "van Doorn", email = "jorva845@student.liu.se", role = "aut"))

Maintainer: Bayu Beta Brahmantio, <bayubrahmantio@gmail.com>

References

~~ Literature or other references for background information ~~


Jorisvdoorn/bonuslabgroup8 documentation built on Oct. 30, 2019, 8:01 p.m.