Description Details Author(s) References
This package contains two functions. The first is an alternative to the linear regression package, this functions is called ridgereg and returns an object with the results of a Ridge regression. The second is a visualisation of mean delay of flights for different airports by longitude and latitude.
The DESCRIPTION file:
This package was not yet installed at build time.
Index: This package was not yet installed at build time.
~~ An overview of how to use the package, including the most ~~
~~ important functions ~~
c(person("Bayu Beta", "Brahmantio", email = "bayubrahmantio@gmail.com", role = c("aut", "cre")), person("Joris", "van Doorn", email = "jorva845@student.liu.se", role = "aut"))
Maintainer: Bayu Beta Brahmantio, <bayubrahmantio@gmail.com>
~~ Literature or other references for background information ~~
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.